FilesConfig

Struct FilesConfig 

pub struct FilesConfig {
Show 15 fields pub paths: Vec<String>, pub format: Option<FileFormat>, pub compression: Option<Compression>, pub file_extension: Option<String>, pub columns: Option<Vec<ColumnConfig>>, pub header: Option<bool>, pub delimiter: Option<String>, pub region: Option<String>, pub role_arn: Option<String>, pub static_credentials: Option<StaticAwsCredentials>, pub endpoint_url: Option<String>, pub force_path_style: Option<bool>, pub allow_http: Option<bool>, pub json_path: Option<String>, pub parser_buffer_size: Option<usize>,
}

Fields

paths: Vec<String>format: Option<FileFormat>compression: Option<Compression>file_extension: Option<String>columns: Option<Vec<ColumnConfig>>header: Option<bool>delimiter: Option<String>region: Option<String>role_arn: Option<String>static_credentials: Option<StaticAwsCredentials>endpoint_url: Option<String>force_path_style: Option<bool>allow_http: Option<bool>json_path: Option<String>

JSONPath to walk at scan time. Optional for format = "json", rejected for other formats. Accepted subset: $, .<name>, ["..."], [*]. When absent (or just $), each top-level JSON document becomes one Variant row. With a terminal [*], each array element along the path becomes one Variant row. With a terminal field, each top-level document’s value at that path becomes one Variant row.

parser_buffer_size: Option<usize>

Working-buffer budget (bytes) for the streaming JSON parser used by json. Defaults to ~1 MiB when None. Rejected for non-json formats.

Implementations

Source

impl FilesConfig

pub fn builder() -> FilesConfigBuilder

Create an instance of FilesConfig using the builder syntax